@@ -3,8 +3,9 @@ package Test::Compile::Internal;
 use warnings;
 use strict;
 
-use version; our $VERSION = version->declare("v3.2.0");
+use version; our $VERSION = version->declare("v3.2.1");
 use File::Find;
+use File::Spec;
 use Test::Builder;
 use IPC::Open3 ();
 
@@ -228,16 +229,6 @@ access to some of its methods.
 
 =over 4
 
-=item C<done_testing()>
-
-Declares that you are done testing, no more tests will be run after this point.
-
-=cut
-sub done_testing {
-    my ($self, @args) = @_;
-    $self->{test}->done_testing(@args);
-}
-
 =item C<ok($test, $name)>
 
 Your basic test. Pass if C<$test> is true, fail if C<$test> is false. Just
@@ -249,6 +240,17 @@ sub ok {
     $self->{test}->ok(@args);
 }
 
+=item C<done_testing()>
+
+Declares that you got to the end of your test plan, no more tests will be run after
+this point.
+
+=cut
+sub done_testing {
+    my ($self, @args) = @_;
+    $self->{test}->done_testing(@args);
+}
+
 =item C<plan(tests =E<gt> $count)>
 
 Defines how many tests you plan to run.
@@ -328,8 +330,9 @@ sub _find_files {
     my ($self, @searchlist) = @_;
 
     my @filelist;
-    my $findfunc = sub {
-        my $fname = $File::Find::name;
+    my $addFile = sub {
+        my ($fname) = @_;
+
         if ( -f $fname ) {
             if ( !($fname =~ m/CVS|\.svn|\.git/) ) {
                 push @filelist, $fname;
@@ -337,8 +340,13 @@ sub _find_files {
         }
     };
 
-    no warnings 'File::Find';
-    find({wanted => $findfunc, no_chdir => 1}, @searchlist);
+    for my $item ( @searchlist ) {
+        $addFile->($item);
+        if ( -d $item ) {
+            no warnings 'File::Find';
+            find({wanted => sub{$addFile->($File::Find::name)}, no_chdir => 1}, $item);
+        }
+    }
     return (sort @filelist);
 }
 
@@ -377,7 +385,7 @@ sub _default_locations {
     my $prefix = -e 'blib' ? "blib" : ".";
     for my $dir ( @dirs ) {
         my $location = File::Spec->catfile($prefix, $dir);
-	if ( -e $location ) {
+        if ( -e $location ) {
             push @locations, $location;
         }
     }
